---
title: Data Binding
page_title: Data Binding - Scheduler - Kendo UI for Vue
description: "Bind the Kendo UI Scheduler wrapper for Vue to local data arrays or remote data services."
slug: databinding_scheduler
position: 1
---

# Data Binding

The Scheduler provides support for binding it to [local data arrays](#toc-binding-to-local-data-arrays) and to [remote data services](#toc-binding-to-remote-data-services).

## Binding to Local Data Arrays

The following example demonstrates how to create a Scheduler and bind it to a local data source.

{% meta height:665 %}
```html-preview
<div id="vueapp" class="vue-app">
    <kendo-scheduler :data-source="localDataSource"
					 :date="date"
					 :height="600"
					 :timezone="'Etc/UTC'">
      <kendo-scheduler-view :type="'day'"></kendo-scheduler-view>
      <kendo-scheduler-view :type="'workWeek'" :selected="true"></kendo-scheduler-view>
      <kendo-scheduler-view :type="'week'"></kendo-scheduler-view>
      <kendo-scheduler-view :type="'month'"></kendo-scheduler-view>
      <kendo-scheduler-view :type="'agenda'"></kendo-scheduler-view>
    </kendo-scheduler>
</div>
```
```js
Vue.use(SchedulerInstaller);

new Vue({
    el: "#vueapp",
	data: {
		date: new Date('2013/6/6'),
		localDataSource: [
			{
			  id: 1,
			  start: new Date("2013/6/6 08:00 AM"),
			  end: new Date("2013/6/6 09:00 AM"),
			  title: "Interview"
			},
			{
			  id: 2,
			  start: new Date("2013/6/6 08:00 AM"),
			  end: new Date("2013/6/6 09:00 AM"),
			  title: "Meeting"
			}
		]
	}
})
```
{% endmeta %}

## Binding to Remote Data Services

You can bind the Scheduler to a remote dataset by either:
* [Using the SchedulerDataSource component](#toc-using-the-schedulerdatasource-component), or
* [Using the `data` method](#toc-using-the-data-method).

### Using the SchedulerDataSource Component

The following example demonstrates how to bind the Scheduler to a remote [SchedulerDataSource component]({% slug overview_schedulerdatasource %}).

```html
<div id="vueapp" class="vue-app">
    <kendo-schedulerdatasource ref="remoteDataSource"
							   :batch="true"
							   transport-read-url="https://demos.telerik.com/kendo-ui/service/tasks"
							   transport-read-data-type="jsonp"
							   transport-update-url="https://demos.telerik.com/kendo-ui/service/tasks/update"
							   transport-update-data-type="jsonp"
							   transport-create-url="https://demos.telerik.com/kendo-ui/service/tasks/create"
							   transport-create-data-type="jsonp"
							   transport-destroy-url="https://demos.telerik.com/kendo-ui/service/tasks/destroy"
							   transport-destroy-data-type="jsonp"
							   :transport-parameter-map="parameterMap"
							   schema-model-id="taskId"
							   :schema-model-fields="fields">
    </kendo-schedulerdatasource>

    <kendo-scheduler data-source-ref="remoteDataSource"
					 :date="date"
					 :startTime="startTime"
					 :height="600"
					 :timezone="'Etc/UTC'">
		<kendo-scheduler-view :type="'day'"></kendo-scheduler-view>
		<kendo-scheduler-view :type="'workWeek'" :selected="true"></kendo-scheduler-view>
		<kendo-scheduler-view :type="'week'"></kendo-scheduler-view>
		<kendo-scheduler-view :type="'month'"></kendo-scheduler-view>
		<kendo-scheduler-view :type="'agenda'"></kendo-scheduler-view>
    </kendo-scheduler>
</div>
```
```js

Vue.use(SchedulerInstaller);
Vue.use(DataSourceInstaller);

new Vue({
    el: "#vueapp",
	data: {
		date: new Date('2013/6/13'),
		startTime: new Date('2013/6/13 07:00 AM'),
		fields: {
			taskId: { from: 'TaskID', type: 'number' },
			title: { from: 'Title', defaultValue: 'No title', validation: { required: true } },
			start: { type: 'date', from: 'Start' },
			end: { type: 'date', from: 'End' },
			startTimezone: { from: 'StartTimezone' },
			endTimezone: { from: 'EndTimezone' },
			description: { from: 'Description' },
			recurrenceId: { from: 'RecurrenceID' },
			recurrenceRule: { from: 'RecurrenceRule' },
			recurrenceException: { from: 'RecurrenceException' },
			isAllDay: { type: 'boolean', from: 'IsAllDay' }
		}
    },
	methods: {
		parameterMap: function (options, operation) {
			if (operation !== 'read' && options.models) {
				return {models: kendo.stringify(options.models)}
			}
		}
    }
})
```

### Using the data Method

The following example demonstrates how to bind the Scheduler to remote data by using the `data` method.

```html
<div id="vueapp" class="vue-app">
	<kendo-scheduler :data-source="remoteDataSource"
					 :date="date"
					 :startTime="startTime"
					 :height="600"
					 :timezone="'Etc/UTC'">
		<kendo-scheduler-view :type="'day'"></kendo-scheduler-view>
		<kendo-scheduler-view :type="'workWeek'" :selected="true"></kendo-scheduler-view>
		<kendo-scheduler-view :type="'week'"></kendo-scheduler-view>
		<kendo-scheduler-view :type="'month'"></kendo-scheduler-view>
		<kendo-scheduler-view :type="'agenda'"></kendo-scheduler-view>
    </kendo-scheduler>
</div>
```
```js

Vue.use(SchedulerInstaller);

new Vue({
    el: "#vueapp",
    data: {
		date: new Date('2013/6/13'),
		startTime: new Date('2013/6/13 07:00 AM'),
		remoteDataSource: new kendo.data.SchedulerDataSource({
			transport: {
				read: {
					url: 'https://demos.telerik.com/kendo-ui/service/tasks',
					dataType: 'jsonp'
				},
				update: {
					url: 'https://demos.telerik.com/kendo-ui/service/tasks/update',
					dataType: 'jsonp'
				},
				create: {
					url: 'https://demos.telerik.com/kendo-ui/service/tasks/create',
					dataType: 'jsonp'
				},
				destroy: {
					url: 'https://demos.telerik.com/kendo-ui/service/tasks/destroy',
					dataType: 'jsonp'
				}
			},
			schema: {
				model: {
					id: "taskId",
					fields: {
						taskId: { from: 'TaskID', type: 'number' },
						title: { from: 'Title', defaultValue: 'No title', validation: { required: true } },
						start: { type: 'date', from: 'Start' },
						end: { type: 'date', from: 'End' },
						startTimezone: { from: 'StartTimezone' },
						endTimezone: { from: 'EndTimezone' },
						description: { from: 'Description' },
						recurrenceId: { from: 'RecurrenceID' },
						recurrenceRule: { from: 'RecurrenceRule' },
						recurrenceException: { from: 'RecurrenceException' },
						isAllDay: { type: 'boolean', from: 'IsAllDay' }
					}
				}
			}
		})
    }
})
```

## Suggested Links

* [Kendo UI SchedulerDataSource Component for Vue]({% slug overview_schedulerdatasource %})
* [Kendo UI DataSource Component](https://docs.telerik.com/kendo-ui/api/javascript/data/datasource)
* [Kendo UI Scheduler for jQuery](https://docs.telerik.com/kendo-ui/controls/scheduling/scheduler/overview)
* [API Reference of the Scheduler Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/scheduler)
